@@ -22,12 +22,13 @@ PATH_CACHE = Path.home() / ".cache/rocks"
 PATH_INDEX = PATH_CACHE / "index"
 PATH_MAPPING = PATH_CACHE / "mapping_aster-astorb.json"
 
-# Dict to hold the asteroid name-number indices at runtime
+# Dict to hold the asteroid name-number indices and mappings at runtime
 INDEX = {}
+MAPPINGS = {}
 
 # ------
 # Welcome to rocks
-__version__ = "1.5.7"
+__version__ = "1.5.11"
 
 GREETING = rf"""
                 _
