@@ -10,6 +10,7 @@ import aiohttp
 import json
 import numpy as np
 import pandas as pd
+from pydantic.utils import deep_update
 from rich.progress import Progress
 
 import rocks
@@ -97,6 +98,7 @@ async def _local_or_remote(id_ssodnet, session, progress_bar, progress, local):
 
     # Local retrieval failed, do remote query
     card = await _query_ssodnet(id_ssodnet, session)
+    card = _postprocess_ssocard(card)
 
     # save to cache
     if card and card is not None:
@@ -135,6 +137,61 @@ async def _query_ssodnet(id_ssodnet, session):
     return response_json
 
 
+def _postprocess_ssocard(card):
+    """Apply ssoCard structure improvements for pydantic deserialization."""
+
+    # ------
+    # Add metadata label, description, unity, format, and symbol to parameters
+    mappings = rocks.utils.load_mappings()
+
+    def make_dict(values):
+        """Turn lower-level dict values into dicts."""
+        for key, value in values.items():
+            if isinstance(value, dict):
+                make_dict(value)
+            else:
+                # These keys are not touched, they don't have metadata
+                if key in ["bibref", "method", "value", "error", "min", "max"]:
+                    continue
+                # Turn non-dict value into dict for merging with metadata
+                values[key] = {"value": value}
+        return values
+
+    # Turn low-level parameters into dictionaries
+    card["parameters"] = make_dict(card["parameters"])
+
+    # Catch for spins
+    for id_ in card["parameters"]["physical"]["spins"]:
+        mappings["parameters"]["physical"]["spins"][id_] = mappings["parameters"][
+            "physical"
+        ]["spins"]["<id>"]
+
+    card = deep_update(card, mappings)
+
+    # ------
+    # Convert spin to list
+    spins = card["parameters"]["physical"]["spins"]
+    spin_solutions = []
+
+    for key, spin in spins.items():
+
+        # spin entries have integer ids
+        if not key.isnumeric():
+            continue
+
+        # convert the spin key to an entry in the solution dict
+        spin["id_"] = {
+            "value": key,
+            "description": "Identifier of the spin axis solution",
+            "format": "%s",
+        }
+
+        spin_solutions.append(spin)
+    card["parameters"]["physical"]["spins"] = spin_solutions
+
+    return card
+
+
 # ------
 def get_datacloud_catalogue(id_ssodnet, catalogue, progress=False, local=True):
     """Retrieve the datacloud catalogue of one or many asteroids, using their SsODNet IDs.
